@@ -70,8 +70,13 @@ define([
       this.setBrowserOffset = $dateDiffService.setBrowserOffset
       try {
         const parsedResult = agentData.data.data
-        let summary = this.formatAgentStatusData(parsedResult.agent_status)
-        let lastAgent = parsedResult.last_registered_agent[0]
+        const summary = this.formatAgentStatusData(
+          parsedResult.agent_status.connection
+        )
+        const agentSynced = this.formatAgentStatusData(
+          parsedResult.agent_status.configuration
+        )
+        const lastAgent = parsedResult.last_registered_agent[0]
         let groups = parsedResult.groups
 
         this.scope.noAgents = summary.Total < 1
@@ -121,10 +126,14 @@ define([
         this.scope.agentsCoverity = agentsCountTotal
           ? (this.scope.agentsCountActive / agentsCountTotal) * 100
           : 0
+        this.scope.agentsSynced = agentSynced
+          ? (agentSynced.Synced / agentSynced.Total) * 100
+          : 0
 
         this.scope.searchBarModel = {
           name: [],
           status: ['active', 'pending', 'disconnect', 'never_connected'],
+          group_config_status: ['synced', 'not synced'],
           group: groups
             ? groups.sort((a, b) => {
                 return a.toString().localeCompare(b.toString())
